..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.



API Docs
========

.. automodule:: invenio_files_rest.ext
   :members:

Models
------

.. automodule:: invenio_files_rest.models
   :members:

Storage
-------

.. automodule:: invenio_files_rest.storage
   :members:

Signals
-------

.. automodule:: invenio_files_rest.signals
   :members:

File streaming
--------------

.. automodule:: invenio_files_rest.helpers
   :members:

Tasks
-----

.. automodule:: invenio_files_rest.tasks
   :members:
   :undoc-members:
    .. for `undoc-members`, see https://github.com/celery/celery/pull/5135

Exceptions
----------

.. automodule:: invenio_files_rest.errors
   :members:

Limiters
--------

.. automodule:: invenio_files_rest.limiters
   :members:

Permissions
-----------

.. automodule:: invenio_files_rest.permissions
   :members:

Views
-----

.. automodule:: invenio_files_rest.views
   :members:

Form parser
-----------

.. automodule:: invenio_files_rest.formparser
   :members:
